from .french_book_reviews import FrenchBookReviews, FrenchBookReviewsV2
from .movie_review_sentiment_classification import (
    MovieReviewSentimentClassification,
    MovieReviewSentimentClassificationV2,
)

__all__ = [
    "FrenchBookReviews",
    "FrenchBookReviewsV2",
    "MovieReviewSentimentClassification",
    "MovieReviewSentimentClassificationV2",
]
