PROGRAMMING_LANGS = [
    "python",
    "javascript",
    "typescript",
    "go",
    "ruby",
    "java",
    "php",
    "c",
    "c++",
    "c#",
    "rust",
    "swift",
    "scala",
    "shell",
    "sql",
]
