from .argu_ana_nl_retrieval import ArguAnaNL, ArguAnaNLv2
from .bbsard_nl_retrieval import BBSARDNLRetrieval
from .climate_fevernl_retrieval import ClimateFEVERNL
from .cqa_dupstack_android_nl_retrieval import CQADupstackAndroidNLRetrieval
from .cqa_dupstack_english_nl_retrieval import CQADupstackEnglishNLRetrieval
from .cqa_dupstack_gaming_nl_retrieval import CQADupstackGamingNLRetrieval
from .cqa_dupstack_gis_nl_retrieval import CQADupstackGisNLRetrieval
from .cqa_dupstack_mathematica_nl_retrieval import CQADupstackMathematicaNLRetrieval
from .cqa_dupstack_physics_nl_retrieval import CQADupstackPhysicsNLRetrieval
from .cqa_dupstack_programmers_nl_retrieval import CQADupstackProgrammersNLRetrieval
from .cqa_dupstack_stats_nl_retrieval import CQADupstackStatsNLRetrieval
from .cqa_dupstack_tex_nl_retrieval import CQADupstackTexNLRetrieval
from .cqa_dupstack_unix_nl_retrieval import CQADupstackUnixNLRetrieval
from .cqa_dupstack_webmasters_nl_retrieval import CQADupstackWebmastersNLRetrieval
from .cqa_dupstack_wordpress_nl_retrieval import CQADupstackWordpressNLRetrieval
from .db_pedia_nl_retrieval import DBPediaNL
from .dutch_news_articles_retrieval import DutchNewsArticlesRetrieval
from .fevernl_retrieval import FEVERNL
from .fi_qa2018_nl_retrieval import FiQA2018NL
from .hotpot_qanl_retrieval import HotpotQANL
from .legal_qa_nl_retrieval import LegalQANLRetrieval
from .mmarconl_retrieval import MMMARCONL
from .nf_corpus_nl_retrieval import NFCorpusNL, NFCorpusNLv2
from .nqnl_retrieval import NQNL
from .open_tender_retrieval import OpenTenderRetrieval
from .quora_nl_retrieval import QuoraNLRetrieval
from .sci_fact_nl_retrieval import SciFactNL, SciFactNLv2
from .scidocsnl_retrieval import SCIDOCSNL, SCIDOCSNLv2
from .touche2020_nl_retrieval import Touche2020NL
from .treccovidnl_retrieval import TRECCOVIDNL
from .vabb_retrieval import VABBRetrieval

__all__ = [
    "FEVERNL",
    "MMMARCONL",
    "NQNL",
    "SCIDOCSNL",
    "TRECCOVIDNL",
    "ArguAnaNL",
    "ArguAnaNLv2",
    "BBSARDNLRetrieval",
    "CQADupstackAndroidNLRetrieval",
    "CQADupstackEnglishNLRetrieval",
    "CQADupstackGamingNLRetrieval",
    "CQADupstackGisNLRetrieval",
    "CQADupstackMathematicaNLRetrieval",
    "CQADupstackPhysicsNLRetrieval",
    "CQADupstackProgrammersNLRetrieval",
    "CQADupstackStatsNLRetrieval",
    "CQADupstackTexNLRetrieval",
    "CQADupstackUnixNLRetrieval",
    "CQADupstackWebmastersNLRetrieval",
    "CQADupstackWordpressNLRetrieval",
    "ClimateFEVERNL",
    "DBPediaNL",
    "DutchNewsArticlesRetrieval",
    "FiQA2018NL",
    "HotpotQANL",
    "LegalQANLRetrieval",
    "NFCorpusNL",
    "NFCorpusNLv2",
    "OpenTenderRetrieval",
    "QuoraNLRetrieval",
    "SCIDOCSNLv2",
    "SciFactNL",
    "SciFactNLv2",
    "Touche2020NL",
    "VABBRetrieval",
]
