from .wisesight_sentiment_classification import (
    WisesightSentimentClassification,
    WisesightSentimentClassificationV2,
)
from .wongnai_reviews_classification import WongnaiReviewsClassification

__all__ = [
    "WisesightSentimentClassification",
    "WisesightSentimentClassificationV2",
    "WongnaiReviewsClassification",
]
