from mteb.abstasks import AbsTaskClustering
from mteb.abstasks.task_metadata import TaskMetadata


class VehicleSoundClustering(AbsTaskClustering):
    metadata = TaskMetadata(
        name="VehicleSoundClustering",
        description="Clustering vehicle sounds recorded from smartphones (0 (car class), 1 (truck, bus and van class), 2 (motorcycle class))",
        reference="https://huggingface.co/datasets/DynamicSuperb/Vehicle_sounds_classification_dataset",
        dataset={
            "path": "mteb/Vehicle_sounds_classification_dataset",
            "revision": "5f905f9544d0c78b607639662c88c2ddd1216384",
        },
        type="AudioClustering",
        category="a2a",
        eval_splits=["test"],
        eval_langs=["zxx-Zxxx"],
        main_score="v_measure",
        date=("2024-06-20", "2024-06-20"),
        domains=["Scene"],
        task_subtypes=["Vehicle Clustering"],
        license="not specified",
        annotations_creators="derived",
        dialect=[],
        modalities=["audio"],
        sample_creation="created",
        bibtex_citation=r"""
@inproceedings{inproceedings,
  author = {Bazilinskyy, Pavlo and Aa, Arne and Schoustra, Michael and Spruit, John and Staats, Laurens and van der Vlist, Klaas Jan and de Winter, Joost},
  month = {05},
  pages = {},
  title = {An auditory dataset of passing vehicles recorded with a smartphone},
  year = {2018},
}
""",
    )

    label_column_name: str = "label"
    input_column_name: str = "audio"
    max_fraction_of_documents_to_embed = None
