from .beir_fa import (
    ArguAnaFa,
    ArguAnaFaV2,
    ClimateFEVERFa,
    CQADupstackAndroidRetrievalFa,
    CQADupstackEnglishRetrievalFa,
    CQADupstackGamingRetrievalFa,
    CQADupstackGisRetrievalFa,
    CQADupstackMathematicaRetrievalFa,
    CQADupstackPhysicsRetrievalFa,
    CQADupstackProgrammersRetrievalFa,
    CQADupstackStatsRetrievalFa,
    CQADupstackTexRetrievalFa,
    CQADupstackUnixRetrievalFa,
    CQADupstackWebmastersRetrievalFa,
    CQADupstackWordpressRetrievalFa,
    DBPediaFa,
    FEVERFaHardNegatives,
    FiQA2018Fa,
    FiQA2018FaV2,
    HotpotQAFa,
    HotpotQAFaHardNegatives,
    MSMARCOFa,
    MSMARCOFaHardNegatives,
    NFCorpusFa,
    NQFa,
    NQFaHardNegatives,
    QuoraRetrievalFa,
    QuoraRetrievalFaV2,
    SCIDOCSFa,
    SCIDOCSFaV2,
    SciFactFa,
    SciFactFaV2,
    Touche2020Fa,
    Touche2020FaV2,
    TRECCOVIDFa,
    TRECCOVIDFaV2,
)
from .fa_mteb_retrieval import (
    PersianWebDocumentRetrieval,
    SynPerChatbotRAGFAQRetrieval,
    SynPerChatbotRAGTopicsRetrieval,
    SynPerChatbotTopicsRetrieval,
    SynPerQARetrieval,
)

__all__ = [
    "ArguAnaFa",
    "ArguAnaFaV2",
    "CQADupstackAndroidRetrievalFa",
    "CQADupstackEnglishRetrievalFa",
    "CQADupstackGamingRetrievalFa",
    "CQADupstackGisRetrievalFa",
    "CQADupstackMathematicaRetrievalFa",
    "CQADupstackPhysicsRetrievalFa",
    "CQADupstackProgrammersRetrievalFa",
    "CQADupstackStatsRetrievalFa",
    "CQADupstackTexRetrievalFa",
    "CQADupstackUnixRetrievalFa",
    "CQADupstackWebmastersRetrievalFa",
    "CQADupstackWordpressRetrievalFa",
    "ClimateFEVERFa",
    "DBPediaFa",
    "FEVERFaHardNegatives",
    "FiQA2018Fa",
    "FiQA2018FaV2",
    "HotpotQAFa",
    "HotpotQAFaHardNegatives",
    "MSMARCOFa",
    "MSMARCOFaHardNegatives",
    "NFCorpusFa",
    "NQFa",
    "NQFaHardNegatives",
    "PersianWebDocumentRetrieval",
    "QuoraRetrievalFa",
    "QuoraRetrievalFaV2",
    "SCIDOCSFa",
    "SCIDOCSFaV2",
    "SciFactFa",
    "SciFactFaV2",
    "SynPerChatbotRAGFAQRetrieval",
    "SynPerChatbotRAGTopicsRetrieval",
    "SynPerChatbotTopicsRetrieval",
    "SynPerQARetrieval",
    "TRECCOVIDFa",
    "TRECCOVIDFaV2",
    "Touche2020Fa",
    "Touche2020FaV2",
]
