from .swedish_patent_cpc_group_classification import SwedishPatentCPCGroupClassification
from .swedish_patent_cpc_subclass_classification import (
    SwedishPatentCPCSubclassClassification,
)

__all__ = [
    "SwedishPatentCPCGroupClassification",
    "SwedishPatentCPCSubclassClassification",
]
