from .ambient_acoustic_context import AmbientAcousticContextClassification
from .beijing_opera import BeijingOpera
from .bird_clef import BirdCLEFClassification
from .esc50 import ESC50Classification
from .gtzan_genre import GTZANGenre
from .gunshot_triangulation import GunshotTriangulation
from .mridingham_stroke import MridinghamStroke
from .mridingham_tonic import MridinghamTonic
from .n_synth import NSynth
from .tau_acoustic_scenes_2022_mobile import TAUAcousticScenes2022Mobile
from .tut_acoustic_scenes import TUTAcousticScenesClassification
from .urban_sound8k import UrbanSound8kClassification

__all__ = [
    "AmbientAcousticContextClassification",
    "BeijingOpera",
    "BirdCLEFClassification",
    "ESC50Classification",
    "GTZANGenre",
    "GunshotTriangulation",
    "MridinghamStroke",
    "MridinghamTonic",
    "NSynth",
    "TAUAcousticScenes2022Mobile",
    "TUTAcousticScenesClassification",
    "UrbanSound8kClassification",
]
