from .esc50 import ESC50ZeroshotClassification
from .urban_sound8k import UrbanSound8kZeroshotClassification

__all__ = [
    "ESC50ZeroshotClassification",
    "UrbanSound8kZeroshotClassification",
]
